export type SuccessResponse = {
    /**
     * Status code for successful operations
     */
    status: 0;
    /**
     * Result payload for the operation
     */
    result: {
        [key: string]: unknown;
    };
};
export type ErrorResponse = {
    /**
     * Status code for error operations
     */
    status: 1;
    /**
     * Error details
     */
    error: {
        [key: string]: unknown;
    };
};
export type SystemError = {
    /**
     * Error code
     */
    code: number;
    /**
     * Error message
     */
    message: string;
    /**
     * Additional error data
     */
    data?: {
        [key: string]: unknown;
    } | null;
};
export type SystemMetricsStatus = {
    cpu: {
        /**
         * Number of CPU cores
         */
        cores: number;
        /**
         * Used CPU resources
         */
        used: number;
        /**
         * Configured CPU resources
         */
        configured: number;
    };
    memory: {
        /**
         * Used memory in bytes
         */
        used: number;
        /**
         * Total available memory in bytes
         */
        total: number;
        /**
         * Configured memory limit in bytes
         */
        configured: number;
    };
    storage: {
        /**
         * Used storage in bytes
         */
        used: number;
        /**
         * Total available storage in bytes
         */
        total: number;
        /**
         * Configured storage limit in bytes
         */
        configured: number;
    };
};
export type InitStatus = {
    /**
     * Status message
     */
    message: string;
    /**
     * Whether the status represents an error
     */
    isError?: boolean | null;
    /**
     * Current progress (0-100)
     */
    progress: number;
    /**
     * Next progress target (0-100)
     */
    nextProgress: number;
    /**
     * Standard output from the initialization process
     */
    stdout?: string | null;
};
export type SystemUpdateData = {
    body: {
        [key: string]: unknown;
    };
    path?: never;
    query?: never;
    url: '/system/update';
};
export type SystemUpdateErrors = {
    /**
     * Error updating system
     */
    400: ErrorResponse & {
        error?: SystemError;
    };
};
export type SystemUpdateError = SystemUpdateErrors[keyof SystemUpdateErrors];
export type SystemUpdateResponses = {
    /**
     * Successful operation
     */
    200: SuccessResponse & {
        result?: {
            [key: string]: unknown;
        };
    };
};
export type SystemUpdateResponse = SystemUpdateResponses[keyof SystemUpdateResponses];
export type SystemHibernateData = {
    body: {
        [key: string]: unknown;
    };
    path?: never;
    query?: never;
    url: '/system/hibernate';
};
export type SystemHibernateErrors = {
    /**
     * Error hibernating system
     */
    400: ErrorResponse & {
        error?: SystemError;
    };
};
export type SystemHibernateError = SystemHibernateErrors[keyof SystemHibernateErrors];
export type SystemHibernateResponses = {
    /**
     * Successful operation
     */
    200: SuccessResponse & {
        result?: unknown;
    };
};
export type SystemHibernateResponse = SystemHibernateResponses[keyof SystemHibernateResponses];
export type SystemMetricsData = {
    body: {
        [key: string]: unknown;
    };
    path?: never;
    query?: never;
    url: '/system/metrics';
};
export type SystemMetricsErrors = {
    /**
     * Error retrieving system metrics
     */
    400: ErrorResponse & {
        error?: SystemError;
    };
};
export type SystemMetricsError = SystemMetricsErrors[keyof SystemMetricsErrors];
export type SystemMetricsResponses = {
    /**
     * Successful operation
     */
    200: SuccessResponse & {
        result?: SystemMetricsStatus;
    };
};
export type SystemMetricsResponse = SystemMetricsResponses[keyof SystemMetricsResponses];
